from sqlalchemy.orm import Session

from messageprocessor import MessageProcessorCallback


class SessionProcessorCallback(MessageProcessorCallback):
    def __init__(self, session):
        # type: (Session) -> None
        self.session = session

    def process_begun(self, event_name, request_id, data):
        pass

    def input_parsed(self, event_name, request_id, input_obj):
        pass

    def business_called(self, event_name, request_id, input_obj, output_obj):
        self.session.commit()

    def process_finished(self, event_name, request_id, input_obj, output_obj):
        pass

    def parse_exception(self, event_name, request_id, data, exception):
        self.session.rollback()

    def unhandled_exception(self, event_name, request_id, input_obj, exception):
        self.session.rollback()



import sys
import six
from sqlalchemy.orm import Session


class SessionUow(object):
    def __init__(self, session):
        # type: (Session) -> None
        self.session = session

    def execute_with_transaction(self, func):
        try:
            ret = func()
            self.session.commit()
            return ret
        except:
            self.session.rollback()
            six.reraise(*sys.exc_info())

    def execute_method_with_transaction(self, obj, method_name, *args, **kwargs):
        def inner_func():
            method = getattr(obj, method_name)
            return method(*args, **kwargs)

        return self.execute_with_transaction(inner_func)



from setuptools import setup, find_packages
setup(name="SqlAlchemyUtil",
      version="0.1",
      packages=find_packages(where="."),
      install_requires=['six', 'sqlalchemy', 'MessageProcessor'],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)